==> antismash-5.2.0.tar.gz: antismash-5.2.0/README.md <==
antiSMASH - the antibiotics and Secondary Metabolite Analysis SHell
===================================================================

Development & Funding
---------------------

The development of antiSMASH was started as a collaboration of the Department of
Microbial Physiology and Groningen Bioinformatics Centre of the University of
Groningen, the Department of Microbiology of the University of Tübingen, and the
Department of Bioengineering and Therapeutic Sciences at the University of
California, San Francisco.  With the move of the PIs and developers, development
continues now at the Manchester Institute of Biotechnology, the Bioinformatics
Group at Wageningen University and The Novo Nordisk Foundation Center for
Biosustainability in Lyngby.

antiSMASH development was/is supported by the GenBiotics program of the Dutch
Technology Foundation (STW), which is the applied-science division of The
Netherlands Organisation for Scientific Research (NWO) and the Technology
Programme of the Ministry of Economic Affairs (grant STW 10463), GenBioCom
program of the German Ministry of Education and Research (BMBF) grant 0315585A,
the German Center for Infection Research (DZIF) and the Novo Nordisk Foundation.

Publications
------------

See http://antismash.secondarymetabolites.org/#!/about for information on citing
antiSMASH.


Installation
------------

There are multiple options on how to get your own copy of antiSMASH up and running.
See [our install documentation](https://docs.antismash.secondarymetabolites.org/install/)
for detailed information.

Note: while efforts are made to keep antiSMASH cross-platform, Windows is not
officially supported.

License
-------

antiSMASH is an open source tool available under the GNU Affero General Public
License version 3.0 or greater. See the [`LICENSE.txt`](LICENSE.txt) file for
details.

Acknowledgements
----------------

Some icons used courtesy of fontawesome.com

==> antismash-8.0.1.tar.gz: antismash-8.0.1/README.md <==
antiSMASH - the antibiotics and Secondary Metabolite Analysis SHell
===================================================================

Development & Funding
---------------------

The development of antiSMASH was started as a collaboration of the Department of
Microbial Physiology and Groningen Bioinformatics Centre of the University of
Groningen, the Department of Microbiology of the University of Tübingen, the Manchester
Institute of Biotechnology, and the Department of Bioengineering and Therapeutic
Sciences at the University of California, San Francisco.
With the move of the PIs and developers, development continues now at the Bioinformatics
Group at Wageningen University and The Novo Nordisk Foundation Center for
Biosustainability in Lyngby.

antiSMASH development was/is supported by the GenBiotics program of the Dutch
Technology Foundation (STW), which is the applied-science division of The
Netherlands Organisation for Scientific Research (NWO) and the Technology
Programme of the Ministry of Economic Affairs (grant STW 10463), GenBioCom
program of the German Ministry of Education and Research (BMBF) grant 0315585A,
the German Center for Infection Research (DZIF) and the Novo Nordisk Foundation.

Publications
------------

See http://antismash.secondarymetabolites.org/#!/about for information on citing
antiSMASH.


Installation
------------

There are multiple options on how to get your own copy of antiSMASH up and running.
See [our install documentation](https://docs.antismash.secondarymetabolites.org/install/)
for detailed information.

Note: while efforts are made to keep antiSMASH cross-platform, Windows is not
officially supported.

License
-------

antiSMASH is an open source tool available under the GNU Affero General Public
License version 3.0 or greater. See the [`LICENSE.txt`](LICENSE.txt) file for
details.

Acknowledgements
----------------

Some icons used courtesy of fontawesome.com
